@@ -53,312 +53,15 @@
 extern "C" {
 #endif
 
-#define ITF8_MACROS
+//#define ITF8_MACROS
 
 #include <stdint.h>
 #include <io_lib/misc.h>
 #include <io_lib/bam.h>
 
-/**@{ ----------------------------------------------------------------------
- * ITF8 encoding and decoding.
- *
- * Also see the itf8_get and itf8_put macros.
- */
-
 /*! INTERNAL: Converts two characters into an integer for use in switch{} */
 #define CRAM_KEY(a,b) (((a)<<8)|((b)))
 
-/*! Reads an integer in ITF-8 encoding from 'fd' and stores it in
- * *val.
- *
- * @return
- * Returns the number of bytes read on success;
- *        -1 on failure
- */
-int itf8_decode(cram_fd *fd, int32_t *val);
-
-#ifndef ITF8_MACROS
-/*! Reads an integer in ITF-8 encoding from 'cp' and stores it in
- * *val.
- *
- * @return
- * Returns the number of bytes read on success;
- *        -1 on failure
- */
-int itf8_get(char *cp, int32_t *val_p);
-
-/*! Stores a value to memory in ITF-8 format.
- *
- * @return
- * Returns the number of bytes required to store the number.
- * This is a maximum of 5 bytes.
- */
-int itf8_put(char *cp, int32_t val);
-
-#else
-
-/*
- * Macro implementations of the above
- */
-#define itf8_get(c,v) (((uc)(c)[0]<0x80)?(*(v)=(uc)(c)[0],1):(((uc)(c)[0]<0xc0)?(*(v)=(((uc)(c)[0]<<8)|(uc)(c)[1])&0x3fff,2):(((uc)(c)[0]<0xe0)?(*(v)=(((uc)(c)[0]<<16)|((uc)(c)[1]<<8)|(uc)(c)[2])&0x1fffff,3):(((uc)(c)[0]<0xf0)?(*(v)=(((uc)(c)[0]<<24)|((uc)(c)[1]<<16)|((uc)(c)[2]<<8)|(uc)(c)[3])&0x0fffffff,4):(*(v)=(((uc)(c)[0]&0x0f)<<28)|((uc)(c)[1]<<20)|((uc)(c)[2]<<12)|((uc)(c)[3]<<4)|((uc)(c)[4]&0x0f),5)))))
-
-#define itf8_put(c,v) ((!((v)&~0x7f))?((c)[0]=(v),1):(!((v)&~0x3fff))?((c)[0]=((v)>>8)|0x80,(c)[1]=(v)&0xff,2):(!((v)&~0x1fffff))?((c)[0]=((v)>>16)|0xc0,(c)[1]=((v)>>8)&0xff,(c)[2]=(v)&0xff,3):(!((v)&~0xfffffff))?((c)[0]=((v)>>24)|0xe0,(c)[1]=((v)>>16)&0xff,(c)[2]=((v)>>8)&0xff,(c)[3]=(v)&0xff,4):((c)[0]=0xf0|(((v)>>28)&0xff),(c)[1]=((v)>>20)&0xff,(c)[2]=((v)>>12)&0xff,(c)[3]=((v)>>4)&0xff,(c)[4]=(v)&0xf,5))
-
-#define itf8_size(v) ((!((v)&~0x7f))?1:(!((v)&~0x3fff))?2:(!((v)&~0x1fffff))?3:(!((v)&~0xfffffff))?4:5)
-
-#endif
-
-int ltf8_put(char *cp, int64_t val);
-
-/* Version of itf8_get that checks it hasn't run out of input */
-
-extern const int itf8_bytes[16];
-extern const int ltf8_bytes[256];
-
-
-static inline int safe_itf8_get(const char *cp, const char *endp,
-				int32_t *val_p) {
-    const unsigned char *up = (unsigned char *)cp;
-
-    if (endp - cp < 5 &&
-	(cp >= endp || endp - cp < itf8_bytes[up[0]>>4])) {
-        *val_p = 0;
-        return 0;
-    }
-
-    if (up[0] < 0x80) {
-	*val_p =   up[0];
-	return 1;
-    } else if (up[0] < 0xc0) {
-	*val_p = ((up[0] <<8) |  up[1])                           & 0x3fff;
-	return 2;
-    } else if (up[0] < 0xe0) {
-	*val_p = ((up[0]<<16) | (up[1]<< 8) |  up[2])             & 0x1fffff;
-	return 3;
-    } else if (up[0] < 0xf0) {
-	*val_p = ((up[0]<<24) | (up[1]<<16) | (up[2]<<8) | up[3]) & 0x0fffffff;
-	return 4;
-    } else {
-	*val_p = ((up[0] & 0x0f)<<28) | (up[1]<<20) | (up[2]<<12) | (up[3]<<4) | (up[4] & 0x0f);
-	return 5;
-    }
-}
-
-static inline int safe_ltf8_get(const char *cp, const char *endp,
-                                int64_t *val_p) {
-    unsigned char *up = (unsigned char *)cp;
-
-    if (endp - cp < 9 && 
-	(cp >= endp || endp - cp < ltf8_bytes[up[0]])) {
-        *val_p = 0;
-        return 0;
-    }
-
-    if (up[0] < 0x80) {
-	*val_p =   up[0];
-	return 1;
-    } else if (up[0] < 0xc0) {
-	*val_p = (((uint64_t)up[0]<< 8) |
-		   (uint64_t)up[1]) & (((1LL<<(6+8)))-1);
-	return 2;
-    } else if (up[0] < 0xe0) {
-	*val_p = (((uint64_t)up[0]<<16) |
-		  ((uint64_t)up[1]<< 8) |
-		   (uint64_t)up[2]) & ((1LL<<(5+2*8))-1);
-	return 3;
-    } else if (up[0] < 0xf0) {
-	*val_p = (((uint64_t)up[0]<<24) |
-		  ((uint64_t)up[1]<<16) |
-		  ((uint64_t)up[2]<< 8) |
-		   (uint64_t)up[3]) & ((1LL<<(4+3*8))-1);
-	return 4;
-    } else if (up[0] < 0xf8) {
-	*val_p = (((uint64_t)up[0]<<32) |
-		  ((uint64_t)up[1]<<24) |
-		  ((uint64_t)up[2]<<16) |
-		  ((uint64_t)up[3]<< 8) |
-		   (uint64_t)up[4]) & ((1LL<<(3+4*8))-1);
-	return 5;
-    } else if (up[0] < 0xfc) {
-	*val_p = (((uint64_t)up[0]<<40) |
-		  ((uint64_t)up[1]<<32) |
-		  ((uint64_t)up[2]<<24) |
-		  ((uint64_t)up[3]<<16) |
-		  ((uint64_t)up[4]<< 8) |
-		   (uint64_t)up[5]) & ((1LL<<(2+5*8))-1);
-	return 6;
-    } else if (up[0] < 0xfe) {
-	*val_p = (((uint64_t)up[0]<<48) |
-		  ((uint64_t)up[1]<<40) |
-		  ((uint64_t)up[2]<<32) |
-		  ((uint64_t)up[3]<<24) |
-		  ((uint64_t)up[4]<<16) |
-		  ((uint64_t)up[5]<< 8) |
-		   (uint64_t)up[6]) & ((1LL<<(1+6*8))-1);
-	return 7;
-    } else if (up[0] < 0xff) {
-	*val_p = (((uint64_t)up[1]<<48) |
-		  ((uint64_t)up[2]<<40) |
-		  ((uint64_t)up[3]<<32) |
-		  ((uint64_t)up[4]<<24) |
-		  ((uint64_t)up[5]<<16) |
-		  ((uint64_t)up[6]<< 8) |
-		   (uint64_t)up[7]) & ((1LL<<(7*8))-1);
-	return 8;
-    } else {
-	*val_p = (((uint64_t)up[1]<<56) |
-		  ((uint64_t)up[2]<<48) |
-		  ((uint64_t)up[3]<<40) |
-		  ((uint64_t)up[4]<<32) |
-		  ((uint64_t)up[5]<<24) |
-		  ((uint64_t)up[6]<<16) |
-		  ((uint64_t)up[7]<< 8) |
-		   (uint64_t)up[8]);
-	return 9;
-    }
-}
-
-static inline int uint7_size(uint64_t v) {
-    int i = 0;
-    do {
-	i++;
-	v >>= 7;
-    } while (v);
-    return i;
-}
-
-static inline int sint7_size(int64_t v) {
-    return uint7_size((v >> 63) ^ (v << 1));
-}
-
-// Unlike itf8 and ltf8 these are agnostic to data size.
-// A 32-bit quantity written using itf8 may be stored differently
-// than the same 32-bit value written using ltf8, which makes it hard
-// to transparently upgrade data sizes.  We also support signed
-// versions using zig-zag encoding, to avoid the problem of a 64-bit
-// -1 taking up 9 bytes.
-static inline int uint7_put(uint8_t *cp, const uint8_t *endp, uint64_t v) {
-    uint8_t *op = cp;
-    int s = 0;
-    uint64_t o = v;
-
-    // big endian for simpler and faster decode.
-    do {
-	s += 7;
-	o >>= 7;
-    } while (o);
-
-    if (endp && (endp-cp)*7 < s)
-	return 0;
-
-    do {
-	s -= 7;
-	*cp++ = ((v>>s)&0x7f) + (s?128:0);
-    } while (s);
-
-    return cp-op;
-}
-
-static inline int sint7_put(uint8_t *cp, const uint8_t *endp, int64_t v) {
-    // zig-zag encoding.
-    return uint7_put(cp, endp, (v >> 63) ^ (v << 1));
-}
-
-// FIXME: Merge with u7tou32 in rANS_static4x16pr.c
-static inline int uint7_get(const uint8_t *cp, const uint8_t *endp, uint64_t *val_p) {
-    const uint8_t *op = cp;
-    uint8_t c;
-    int64_t v = 0;
-
-    if (endp) {
-	if (cp >= endp) {
-	    *val_p = 0;
-	    return 0;
-	}
-
-	do {
-	    c = *cp++;
-	    v = (v<<7) | (c & 0x7f);
-	} while ((c & 0x80) && cp < endp);
-    } else {
-	do {
-	    c = *cp++;
-	    v = (v<<7) | (c & 0x7f);
-	} while (c & 0x80);
-    }
-
-    *val_p = v;
-    return cp - op;
-}
-
-static inline int sint7_get(const uint8_t *cp, const uint8_t *endp, int64_t *v) {
-    uint64_t u;
-    int d = uint7_get(cp, endp, &u);
-    *v = (u >> 1) ^ -(u & 1);
-    return d;
-}
-
-int uint7_put_blk(cram_block *blk, uint64_t v);
-int sint7_put_blk(cram_block *blk, int64_t v);
-
-/*! Pushes a value in ITF8 format onto the end of a block.
- *
- * This shouldn't be used for high-volume data as it is not the fastest
- * method.
- *
- * @return
- * Returns the number of bytes written
- */
-int itf8_put_blk(cram_block *blk, int32_t val);
-int ltf8_put_blk(cram_block *blk, int64_t val);
-
-/*
- * An alternative to itf8 and ltf8 is simple 7-bit encoding with the top
- * bit implying more data.  This is helpful for several reasons.
- * 1. It's the same encoding for 32-bit and 64-bit so upgrading a data
- *    type is transparent and doesn't change format.
- * 2. The top bit set implies this value is internal to a larger integer,
- *    rather than this only being true for the first in N bytes.  This in
- *    turn reduces the entropy and offers marginal compression gains (0.1%).
- * 3. It's way simpler!
- *
- * Unfortunately the around 150+ uses of itf8/ltf8 so changing everywhere is
- * a lot of work.  The ifdef below isn't for CRAM 4, but just unilaterally
- * changes every use (thus breaking old files) for testing purposes only.
- * See also cram_io.c.
- *
- * I think it's clearly a case of we wouldn't have started from here,
- * we're there now so may as well keep with it.
- */
-#ifdef USE_INT7_ENCODING
-#include <stdint.h>
-static inline int uint7_get_32(const uint8_t *cp, const uint8_t *endp, uint32_t *val_p) {
-    uint64_t v;
-    int r = uint7_get(cp, endp, &v);
-    *val_p = v;
-    return r;
-}
-
-#define safe_itf8_get uint7_get_32
-#define safe_ltf8_get uint7_get
-#undef itf8_size
-#undef itf8_get
-#undef ltf8_get
-#define itf8_size uint7_size
-#define itf8_get(cp,val) uint7_get_32((uint8_t *)(cp),NULL,(val))
-#define ltf8_get(cp,val) uint7_get((uint8_t *)(cp),NULL,(val))
-#define itf8_put_blk uint7_put_blk
-#define ltf8_put_blk uint7_put_blk
-#undef itf8_put
-#undef ltf8_put
-#define itf8_put(cp,val) uint7_put((uint8_t *)(cp),NULL,(val))
-#define ltf8_put(cp,val) uint7_put((uint8_t *)(cp),NULL,(val))
-#define itf8_decode_crc uint7_decode_crc32
-#define ltf8_decode_crc uint7_decode_crc
-#define itf8_encode uint7_encode
-#endif
-
-/**@}*/
 /**@{ ----------------------------------------------------------------------
  * CRAM blocks - the dynamically growable data block. We have code to
  * create, update, (un)compress and read/write.
@@ -420,7 +123,7 @@ int cram_uncompress_block(cram_block *b);
  */
 int cram_compress_block(cram_fd *fd, cram_slice *slice,
 			cram_block *b, cram_metrics *metrics,
-			int method, int level);
+			int64_t method, int level);
 
 cram_metrics *cram_new_metrics(void);
 char *cram_block_method2str(enum cram_block_method m);
@@ -722,6 +425,18 @@ cram_slice *cram_read_slice(cram_fd *fd);
  * CRAM file definition (header)
  */
 
+/*
+ *! Sets CRAM variable sized integer decode function tables.
+ *
+ * CRAM 1, 2, and 3.x all used ITF8 for uint32 and UTF8 for uint64.
+ * CRAM 4.x uses the same encoding mechanism for 32-bit and 64-bit
+ * (or anything inbetween), but also now supports signed values.
+ *
+ * Version is the CRAM major version number.
+ * vv is the vector table (probably &cram_fd->vv)
+ */
+void cram_init_varint(varint_vec *vv, int version);
+
 /*! Reads a CRAM file definition structure.
  *
  * @return
